import enum


class MMChoice(enum.Enum):
    YES = "🔵"
    MAYBE = "❔"
    LATE_SHORT = "🕐"
    LATE_MEDIUM = "🕒"
    LATE_LONG = "🕗"
    NO = "❌"
